@@ -189,7 +189,10 @@ def get_numeric_restrictions_text(schema_node: SchemaNode, before_value: str = "
 
 
 def escape_property_name_for_id(property_name: str) -> str:
-    """Filter. Escape unsafe characters in a property name so that it can be used in a HTML id"""
+    """Filter. Escape unsafe characters in a property name so that it can be used in an HTML id"""
+    if not property_name:
+        # Handle empty string as a property name
+        return ""
 
     escaped = re.sub("[^0-9a-zA-Z_-]", "_", str(property_name))
     if not escaped[0].isalpha():
@@ -220,8 +223,11 @@ def highlight_json_example(example_text: str) -> str:
 
 def yaml_example(example_text: str) -> str:
     """Filter. Return a YAML version of the provided JSON text"""
-    yaml_text = yaml.dump(json.loads(example_text), allow_unicode=True, sort_keys=False)
-    return yaml_text
+    loaded_example = json.loads(example_text)
+    if not isinstance(loaded_example, dict):
+        # YAML dump does not like things that are not object
+        return str(loaded_example)
+    return yaml.dump(loaded_example, allow_unicode=True, sort_keys=False)
 
 
 def highlight_yaml_example(example_text: str) -> str:
